==> 0.0.2.tar.gz: lib/ads/yf_ads_banner_view.dart <==
import 'dart:convert';
import 'dart:core';
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:yf_ads/callbacks/yf_ads_callback.dart';
import 'package:yf_ads/sizes/yf_ads_banner_size.dart';
import 'package:yf_ads/sizes/yf_ads_banner_android_size.dart';
import 'package:yf_ads/sizes/yf_ads_banner_ios_size.dart';
import 'package:yf_ads/bean/yf_ads_banner_bean.dart';
import 'package:yf_ads/yf_ads.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/rendering.dart';
import 'package:yf_ads/sizes/yf_ads_express_banner_ios_size.dart';

class YFAdsBannerView extends StatelessWidget {
  ///just for left and right
  final double? marginSize;

  ///just for top
  final double? topMarginSize;
  final double? cornerSize;
  final String? positionId;
  final bool? showDislike;

  ///判断是否是爱奇艺广告位
  final bool? aqyAd;

  ///判断是否是模板banner广告位
  final bool? expressAd;

  ///though it define dynamic type,but it must be [AndroidBannerAdType] or [IOSBannerAdType]
  final dynamic adSizeType;

  ///just for Android flatform
  final double? heightOffset;

  ///just for ios platform
  final bool? aliAd;
  final Function(YFAdsCallBack)? onAdCallBack;

  ///if you want to load several banner ad in list view,
  ///you must set uniqueId parameter with unique value for every item
  final int? uniqueId;

  const YFAdsBannerView(
      {Key? key,
      @required this.adSizeType,
      this.marginSize = 12,
      this.cornerSize = 0,
      this.topMarginSize = 0,
      this.onAdCallBack,
      this.uniqueId = -1,
      @required this.positionId,
      this.showDislike = true,
      this.aqyAd = false,
      this.expressAd = false,
      this.heightOffset = 0,
      this.aliAd = false})
      : super(key: key);

  final viewType = "com.yf/banner_platform_view";

  Size _getSize(BuildContext context, int adSizeIndex, bool expressAd,
      BannerAdSize bannerAdSizeImpl) {
    double screenWidth = MediaQuery.of(context).size.width;
    if (!expressAd) {
      double width =
          bannerAdSizeImpl.getWidth(adSizeIndex, screenWidth, marginSize!);
      double height =
          bannerAdSizeImpl.getHeight(adSizeIndex, width, heightOffset!, aliAd!);
      return Size(width, height);
    }
    return bannerAdSizeImpl.getExpressBannerAdWidth(
        adSizeIndex, screenWidth, marginSize!, aqyAd!);
  }

  @override
  Widget build(BuildContext context) {
    int adSizeIndex = 0;
    BannerAdSize bannerAdSizeImpl;
    if (Platform.isIOS) {
      if (expressAd!) {
        bannerAdSizeImpl = IosExpressBannerAdSize();
        if (aqyAd!) {
          adSizeIndex = IQYIOSExpressBannerAdType.values
              .indexOf(adSizeType! as IQYIOSExpressBannerAdType);
        } else {
          adSizeIndex = IOSExpressBannerAdType.values
              .indexOf(adSizeType! as IOSExpressBannerAdType);
        }
      } else {
        bannerAdSizeImpl = IOSBannerAdSize();
        print("adSizeType---->:${adSizeType}");

        adSizeIndex =
            IOSBannerAdType.values.indexOf(adSizeType! as IOSBannerAdType);
      }
    } else {
      bannerAdSizeImpl = AndroidBannerAdSize();
      adSizeIndex = AndroidBannerAdType.values
          .indexOf(adSizeType! as AndroidBannerAdType);
    }
    Size calSize = _getSize(context, adSizeIndex, expressAd!, bannerAdSizeImpl);
    print(
        "WH requestBannerAd. width: ${calSize.width} and height: ${calSize.height} and adSizeIndex: $adSizeIndex");

    var reaperBannerBean = YFAdsBannerBean(
        uniqueKey: uniqueId,
        //广告宽
        width: calSize.width.toInt(),
        //广告高
        height: calSize.height.toInt(),
        //是否展示关闭按钮
        showDislike: showDislike,
        //banner尺寸
        adSizeIndex: adSizeIndex,
        //广告背景圆角
        cornerSize: cornerSize!.toInt(),
        //当前广告位是否是爱奇艺广告
        aqyAd: aqyAd,
        //广告位id
        positionId: positionId);

    var createParams = jsonEncode(reaperBannerBean);
    print("createParams is $createParams");

    Widget androidPlatformView() {
      return PlatformViewLink(
        viewType: viewType,
        surfaceFactory:
            (BuildContext context, PlatformViewController controller) {
          //PlatformViewSurface
          return AndroidViewSurface(
            controller: controller as AndroidViewController,
            gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
            hitTestBehavior: PlatformViewHitTestBehavior.opaque,
          );
        },
        onCreatePlatformView: (PlatformViewCreationParams params) {
          print("paramsId: ${params.id}");
          return PlatformViewsService.initSurfaceAndroidView(
            id: params.id,
            viewType: viewType,
            layoutDirection: TextDirection.ltr,
            creationParams: createParams,
            creationParamsCodec: const StandardMessageCodec(),
          )
            ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
            ..create();
        },
      );
    }

    Widget iosPlatformView() {
      return UiKitView(
          layoutDirection: TextDirection.ltr,
          viewType: viewType,
          creationParams: createParams,
          creationParamsCodec: const StandardMessageCodec());
    }

    var reaperPlugin = YFAds.instance;
    reaperPlugin.setBannerAdCallBackFunction(onAdCallBack);
    double bannerWidgetHeight = calSize.height;
    if (Platform.isIOS && !expressAd!) {
      IOSBannerAdSize iosBannerAdSize = bannerAdSizeImpl as IOSBannerAdSize;
      bannerWidgetHeight =
          iosBannerAdSize.getRealHeightForWidget(adSizeIndex, calSize.width);
    }
    print("WH banner view height is $bannerWidgetHeight");
    var margin = EdgeInsets.only(top: topMarginSize!);
    print("WH banner view margin is $margin");
    return Align(
        alignment: Alignment.topCenter,
        child: Container(
          margin: EdgeInsets.only(top: topMarginSize!),
          decoration: BoxDecoration(
              borderRadius: BorderRadius.all(Radius.circular(cornerSize!))),
          width: calSize.width,
          height: bannerWidgetHeight,
          child: Platform.isIOS ? iosPlatformView() : androidPlatformView(),
        ));
  }
}

==> 0.0.9.tar.gz: lib/ads/yf_ads_banner_view.dart <==
import 'dart:convert';
import 'dart:core';
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:yf_ads/callbacks/yf_ads_callback.dart';
import 'package:yf_ads/sizes/yf_ads_banner_size.dart';
import 'package:yf_ads/sizes/yf_ads_banner_android_size.dart';
import 'package:yf_ads/sizes/yf_ads_banner_ios_size.dart';
import 'package:yf_ads/bean/yf_ads_banner_bean.dart';
import 'package:yf_ads/yf_ads.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/rendering.dart';
import 'package:yf_ads/sizes/yf_ads_express_banner_ios_size.dart';

class YFAdsBannerView extends StatelessWidget {
  ///just for left and right
  final double? marginSize;

  ///just for top
  final double? topMarginSize;
  final double? cornerSize;
  final String? positionId;
  final bool? showDislike;
  final double? height;
  final double? width;

  ///判断是否是爱奇艺广告位
  final bool? aqyAd;

  ///判断是否是模板banner广告位
  final bool? expressAd;

  ///though it define dynamic type,but it must be [AndroidBannerAdType] or [IOSBannerAdType]
  final dynamic adSizeType;

  ///just for Android flatform
  final double? heightOffset;

  ///just for ios platform
  final bool? aliAd;
  final Function(YFAdsCallBack)? onAdCallBack;

  ///if you want to load several banner ad in list view,
  ///you must set uniqueId parameter with unique value for every item
  final String? uniqueId;

  const YFAdsBannerView(
      {Key? key,
      @required this.adSizeType,
      this.height = 0,
      this.width = 0,
      this.marginSize = 12,
      this.cornerSize = 0,
      this.topMarginSize = 0,
      this.onAdCallBack,
      this.uniqueId = '-1',
      @required this.positionId,
      this.showDislike = true,
      this.aqyAd = false,
      this.expressAd = false,
      this.heightOffset = 0,
      this.aliAd = false})
      : super(key: key);

  final viewType = "com.yf/banner_platform_view";

  Size _getSize(BuildContext context, int adSizeIndex, bool expressAd,
      BannerAdSize bannerAdSizeImpl) {
    double screenWidth = MediaQuery.of(context).size.width;
    if (!expressAd) {
      double width =
          bannerAdSizeImpl.getWidth(adSizeIndex, screenWidth, marginSize!);
      double height =
          bannerAdSizeImpl.getHeight(adSizeIndex, width, heightOffset!, aliAd!);
      return Size(width, height);
    }
    return bannerAdSizeImpl.getExpressBannerAdWidth(
        adSizeIndex, screenWidth, marginSize!, aqyAd!);
  }

  @override
  Widget build(BuildContext context) {
    int adSizeIndex = 0;
    Size calSize;
    BannerAdSize bannerAdSizeImpl;
    if (Platform.isIOS) {
      // if (expressAd!) {
      //   bannerAdSizeImpl = IosExpressBannerAdSize();
      //   if (aqyAd!) {
      //     adSizeIndex = IQYIOSExpressBannerAdType.values
      //         .indexOf(adSizeType! as IQYIOSExpressBannerAdType);
      //   } else {
      //     adSizeIndex = IOSExpressBannerAdType.values
      //         .indexOf(adSizeType! as IOSExpressBannerAdType);
      //   }
      // } else {
      //   bannerAdSizeImpl = IOSBannerAdSize();
      //   print("adSizeType---->:${adSizeType}");
      //
      //   adSizeIndex =
      //       IOSBannerAdType.values.indexOf(adSizeType! as IOSBannerAdType);
      // }

      calSize = Size(this.width!, this.height!);
    } else {
      bannerAdSizeImpl = AndroidBannerAdSize();
      adSizeIndex = AndroidBannerAdType.values
          .indexOf(adSizeType! as AndroidBannerAdType);
      calSize = _getSize(context, adSizeIndex, expressAd!, bannerAdSizeImpl);
    }

    print(
        "requestBannerAd. width: ${calSize.width} and height: ${calSize.height} and adSizeIndex: $adSizeIndex");

    var reaperBannerBean = YFAdsBannerBean(
        uniqueKey: uniqueId,
        //广告宽
        width: calSize.width.toInt(),
        //广告高
        height: calSize.height.toInt(),
        //是否展示关闭按钮
        showDislike: showDislike,
        //banner尺寸
        adSizeIndex: adSizeIndex,
        //广告背景圆角
        cornerSize: cornerSize!.toInt(),
        //当前广告位是否是爱奇艺广告
        aqyAd: aqyAd,
        loadAndShow: true,
        //广告位id
        positionId: positionId);

    var createParams = jsonEncode(reaperBannerBean);
    print("createParams is $createParams");

    Widget androidPlatformView() {
      return PlatformViewLink(
        viewType: viewType,
        surfaceFactory:
            (BuildContext context, PlatformViewController controller) {
          //PlatformViewSurface
          return AndroidViewSurface(
            controller: controller as AndroidViewController,
            gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
            hitTestBehavior: PlatformViewHitTestBehavior.opaque,
          );
        },
        onCreatePlatformView: (PlatformViewCreationParams params) {
          print("paramsId: ${params.id}");
          return PlatformViewsService.initSurfaceAndroidView(
            id: params.id,
            viewType: viewType,
            layoutDirection: TextDirection.ltr,
            creationParams: createParams,
            creationParamsCodec: const StandardMessageCodec(),
          )
            ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
            ..create();
        },
      );
    }

    Widget iosPlatformView() {
      return UiKitView(
          layoutDirection: TextDirection.ltr,
          viewType: viewType,
          creationParams: createParams,
          creationParamsCodec: const StandardMessageCodec());
    }

    var reaperPlugin = YFAds.instance;
    reaperPlugin.setBannerAdCallBackFunction(onAdCallBack);
    double bannerWidgetHeight = calSize.height;
    if (Platform.isIOS && !expressAd!) {
      // IOSBannerAdSize iosBannerAdSize = bannerAdSizeImpl as IOSBannerAdSize;
      // bannerWidgetHeight =
      //     iosBannerAdSize.getRealHeightForWidget(adSizeIndex, calSize.width);
    }
    print("WH banner view height is $bannerWidgetHeight");
    var margin = EdgeInsets.only(top: topMarginSize!);
    print("WH banner view margin is $margin");
    return Align(
        alignment: Alignment.topCenter,
        child: Container(
          margin: EdgeInsets.only(top: topMarginSize!),
          decoration: BoxDecoration(
              borderRadius: BorderRadius.all(Radius.circular(cornerSize!))),
          width: calSize.width,
          height: bannerWidgetHeight,
          child: Platform.isIOS ? iosPlatformView() : androidPlatformView(),
        ));
  }
}
